Page 47 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 47

Home

    Orleaniste Conspiracy. This resulted in public exposure
    of the conspiracy and the exile of the Duke of Orleans.
    Unfortunately, this did not put an end to its role in the
    French Revolution.

    After a period of nearly three years the third great
    outbreak occurred, the siege of the Tuileries on August
    10, 1792. This occurred at a time when the Jacobin

    Clubs literally ruled France. In 1789 the people had
    chosen their representatives, but due largely to the
    influence of Robespierre (another member of the
    Illuminati), those men who had worked out the

    Illuminati), those men who had worked out. the
    Constitution of 1791 were not allowed to be members of

    This society extending everywhere its numerous
    affiliations, made use of the provincial clubs to make
    itself master of the elections. All the cranks, all the

    seditious scribblers, all the agitators were chosen to go
    and represent the nation, . . &

    By day these representatives of the Jacobin Clubs sat
    in the Assembly and blocked any real progress toward
    reforms by endless quibbling over unimportant details.
    By night they met in secret circles plotting revolution.

    As we view the third great uprising, we begin to see
    the true face of the Revolution with the mask of "reform"

    42

    The Secret Side of History

    those men

    worked out the

    the new States General.

    Referring to the Jacobin Clubs, Dumouriez said:

    ripped away.